summaryrefslogtreecommitdiffstats
path: root/lib/kotext/KoComplexText.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kotext/KoComplexText.h')
-rw-r--r--lib/kotext/KoComplexText.h100
1 files changed, 50 insertions, 50 deletions
diff --git a/lib/kotext/KoComplexText.h b/lib/kotext/KoComplexText.h
index 8349c66d..f4f4253f 100644
--- a/lib/kotext/KoComplexText.h
+++ b/lib/kotext/KoComplexText.h
@@ -7,27 +7,27 @@
**
** Copyright (C) 2001 Trolltech AS. All rights reserved.
**
-** This file is part of the kernel module of the Qt GUI Toolkit.
+** This file is part of the kernel module of the TQt GUI Toolkit.
**
** This file may be distributed under the terms of the Q Public License
** as defined by Trolltech AS of Norway and appearing in the file
-** LICENSE.QPL included in the packaging of this file.
+** LICENSE.TQPL included in the packaging of this file.
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.
**
-** Licensees holding valid Qt Enterprise Edition or Qt Professional Edition
-** licenses may use this file in accordance with the Qt Commercial License
+** Licensees holding valid TQt Enterprise Edition or TQt Professional Edition
+** licenses may use this file in accordance with the TQt Commercial License
** Agreement provided with the Software.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
**
** See http://www.trolltech.com/pricing.html or email sales@trolltech.com for
-** information about Qt Commercial License Agreements.
-** See http://www.trolltech.com/qpl/ for QPL licensing information.
+** information about TQt Commercial License Agreements.
+** See http://www.trolltech.com/qpl/ for TQPL licensing information.
** See http://www.trolltech.com/gpl/ for GPL licensing information.
**
** Contact info@trolltech.com if any conditions of this licensing are
@@ -35,68 +35,68 @@
**
**********************************************************************/
-#ifndef QCOMPLEXTEXT_H
-#define QCOMPLEXTEXT_H
+#ifndef TQCOMPLEXTEXT_H
+#define TQCOMPLEXTEXT_H
//
// W A R N I N G
// -------------
//
-// This file is not part of the Qt API. It exists for the convenience
-// of Qt Remote Control. This header file may change from version to
+// This file is not part of the TQt API. It exists for the convenience
+// of TQt Remote Control. This header file may change from version to
// version without notice, or even be removed.
//
// We mean it.
//
//
-#ifndef QT_H
-#include <qstring.h>
-#include <qpointarray.h>
-#include <qfont.h>
-#include <qpainter.h>
-#include <qptrlist.h>
-#include <qshared.h>
-#endif // QT_H
-
-#ifndef QT_NO_COMPLEXTEXT
-
-// bidi helper classes. Internal to Qt
-struct Q_EXPORT KoBidiStatus {
- KoBidiStatus() {
- eor = QChar::DirON;
- lastStrong = QChar::DirON;
- last = QChar:: DirON;
+#ifndef TQT_H
+#include <tqstring.h>
+#include <tqpointarray.h>
+#include <tqfont.h>
+#include <tqpainter.h>
+#include <tqptrlist.h>
+#include <tqshared.h>
+#endif // TQT_H
+
+#ifndef TQT_NO_COMPLEXTEXT
+
+// bidi helper classes. Internal to TQt
+struct TQ_EXPORT KoBiditqStatus {
+ KoBiditqStatus() {
+ eor = TQChar::DirON;
+ lastStrong = TQChar::DirON;
+ last = TQChar:: DirON;
}
- QChar::Direction eor;
- QChar::Direction lastStrong;
- QChar::Direction last;
+ TQChar::Direction eor;
+ TQChar::Direction lastStrong;
+ TQChar::Direction last;
};
-struct Q_EXPORT KoBidiContext : public QShared {
- // ### ref and deref parent?
- KoBidiContext( uchar level, QChar::Direction embedding, KoBidiContext *parent = 0, bool override = FALSE );
+struct TQ_EXPORT KoBidiContext : public TQShared {
+ // ### ref and deref tqparent?
+ KoBidiContext( uchar level, TQChar::Direction embedding, KoBidiContext *tqparent = 0, bool override = FALSE );
~KoBidiContext();
unsigned char level;
bool override : 1;
- QChar::Direction dir : 5;
+ TQChar::Direction dir : 5;
- KoBidiContext *parent;
+ KoBidiContext *tqparent;
};
-struct Q_EXPORT KoBidiControl {
+struct TQ_EXPORT KoBidiControl {
KoBidiControl() { context = 0; }
- KoBidiControl( KoBidiContext *c, KoBidiStatus s)
+ KoBidiControl( KoBidiContext *c, KoBiditqStatus s)
{ context = c; if( context ) context->ref(); status = s; }
~KoBidiControl() { if ( context && context->deref() ) delete context; }
void setContext( KoBidiContext *c ) { if ( context == c ) return; if ( context && context->deref() ) delete context; context = c; context->ref(); }
KoBidiContext *context;
- KoBidiStatus status;
+ KoBiditqStatus status;
};
-struct Q_EXPORT KoTextRun {
- KoTextRun(int _start, int _stop, KoBidiContext *context, QChar::Direction dir);
+struct TQ_EXPORT KoTextRun {
+ KoTextRun(int _start, int _stop, KoBidiContext *context, TQChar::Direction dir);
int start;
int stop;
@@ -104,7 +104,7 @@ struct Q_EXPORT KoTextRun {
uchar level;
};
-class Q_EXPORT KoComplexText {
+class TQ_EXPORT KoComplexText {
public:
enum Shape {
XIsolated,
@@ -112,20 +112,20 @@ public:
XInitial,
XMedial
};
- static Shape glyphVariant( const QString &str, int pos);
- static Shape glyphVariantLogical( const QString &str, int pos);
+ static Shape glyphVariant( const TQString &str, int pos);
+ static Shape glyphVariantLogical( const TQString &str, int pos);
- static QString shapedString( const QString &str, int from = 0, int len = -1, QPainter::TextDirection dir = QPainter::Auto, const QFontMetrics *fm = 0);
- static QChar shapedCharacter(const QString &str, int pos, const QFontMetrics *fm = 0);
+ static TQString tqshapedString( const TQString &str, int from = 0, int len = -1, TQPainter::TextDirection dir = TQPainter::Auto, const TQFontMetrics *fm = 0);
+ static TQChar tqshapedCharacter(const TQString &str, int pos, const TQFontMetrics *fm = 0);
// positions non spacing marks relative to the base character at position pos.
- //static QPointArray positionMarks( QFontPrivate *f, const QString &str, int pos, QRect *boundingRect = 0 );
+ //static TQPointArray positionMarks( TQFontPrivate *f, const TQString &str, int pos, TQRect *boundingRect = 0 );
- static QPtrList<KoTextRun> *bidiReorderLine( KoBidiControl *control, const QString &str, int start, int len,
- QChar::Direction basicDir = QChar::DirON );
- static QString bidiReorderString( const QString &str, QChar::Direction basicDir = QChar::DirON );
+ static TQPtrList<KoTextRun> *bidiReorderLine( KoBidiControl *control, const TQString &str, int start, int len,
+ TQChar::Direction basicDir = TQChar::DirON );
+ static TQString bidiReorderString( const TQString &str, TQChar::Direction basicDir = TQChar::DirON );
};
-#endif //QT_NO_COMPLEXTEXT
+#endif //TQT_NO_COMPLEXTEXT
#endif